@@ -1,13 +1,17 @@
+import shlex
 from typing import (
     Any,
     Dict,
-    Iterable,
-    MutableMapping,
+    Mapping,
     Optional,
+    Sequence,
     Type,
+    Tuple,
     TYPE_CHECKING,
+    Union,
 )
 from .base import PoeTask
+from ..helpers.env import resolve_envvars
 
 if TYPE_CHECKING:
     from ..config import PoeConfig
@@ -19,24 +23,23 @@ class RefTask(PoeTask):
     A task consisting of a reference to another task
     """
 
-    # TODO: support extending/overriding env or other configuration of the referenced task
-
     content: str
 
     __key__ = "ref"
-    __options__: Dict[str, Type] = {}
+    __options__: Dict[str, Union[Type, Tuple[Type, ...]]] = {}
 
     def _handle_run(
         self,
         context: "RunContext",
-        extra_args: Iterable[str],
-        env: MutableMapping[str, str],
+        extra_args: Sequence[str],
+        env: Mapping[str, str],
     ) -> int:
         """
         Lookup and delegate to the referenced task
         """
-        task = self.from_config(self.content, self._config, ui=self._ui)
-        return task.run(context=context, extra_args=extra_args, env=env,)
+        invocation = tuple(shlex.split(resolve_envvars(self.content, env)))
+        task = self.from_config(invocation[0], self._config, self._ui, invocation)
+        return task.run(context=context, extra_args=extra_args, env=env)
 
     @classmethod
     def _validate_task_def(
@@ -46,7 +49,9 @@ class RefTask(PoeTask):
         Check the given task definition for validity specific to this task type and
         return a message describing the first encountered issue if any.
         """
-        if task_def["ref"] not in config.tasks:
-            return f"Task {task_name!r} contains reference to unkown task {task_def['ref']!r}"
+        task_ref = task_def["ref"]
+
+        if shlex.split(task_ref)[0] not in config.tasks:
+            return f"Task {task_name!r} contains reference to unkown task {task_ref!r}"
 
         return None
